@@ -1,4 +1,4 @@
-# $Id: Snapshot.pm 49466 2008-01-10 19:56:49Z wsnyder $
+# $Id: Snapshot.pm 51888 2008-03-10 13:49:46Z wsnyder $
 # Author: Bryce Denney <bryce.denney@sicortex.com>
 ######################################################################
 #
@@ -64,7 +64,7 @@ use vars qw($AUTOLOAD);
 
 use SVN::S4::Path;
 
-our $VERSION = '1.022';
+our $VERSION = '1.030';
 our $Info = 1;
 
 
@@ -267,8 +267,9 @@ sub snapshot_main {
 	2 => gen_section_divider(2), 
 	3 => gen_section_divider(3)
     );
-    my $rev = '$Id: Snapshot.pm 49466 2008-01-10 19:56:49Z wsnyder $';
-    $rev =~ s/^\$Id: \S+ ([0-9]+) (.*)/$1/ or die "%Error: Failed to parse id string: $rev";
+    my $rev = '$Id: Snapshot.pm 51888 2008-03-10 13:49:46Z wsnyder $';
+    $rev =~ s/^\$ I d:\s*\S+\s*([0-9]+).*$/$1/x or die "failed to parse id string: $rev";
+
     print STDOUT qq{#!/bin/bash -x
 # This file is a s4 snapshot file, created by SVN::S4::Snapshot.pm rev $rev,
 # that describes how to recreate a subversion working area.  If you run this
@@ -559,7 +560,7 @@ sub get_svn_url {
 }
 
 sub usage {
-    print '$Id: Snapshot.pm 49466 2008-01-10 19:56:49Z wsnyder $ ', "\n";
+    print '$Id: Snapshot.pm 51888 2008-03-10 13:49:46Z wsnyder $ ', "\n";
     $SIG{__WARN__} = sub{};     #pod2text isn't clean.
     pod2text($0);
     exit 1;
@@ -714,7 +715,7 @@ SVN::S4::Snapshot
 
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN and from L<http://www.veripool.com/>.
+The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
 Copyright 2005-2008 by Bryce Denney.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
